diff src/os/solaris/vm/os_solaris.cpp @ 4082:36b057451829

7110017: is_headless_jre should be updated to reflect the new location of awt toolkit libraries Reviewed-by: dholmes, dsamersoff Contributed-by: Chris Hegarty <chris.hegarty@oracle.com>
author dholmes
date Wed, 16 Nov 2011 20:38:24 -0500
parents 436b4a3231bf
children e7dead7e90af 11c26bfcf8c7
line wrap: on
line diff
--- a/src/os/solaris/vm/os_solaris.cpp	Tue Nov 15 12:40:55 2011 -0500
+++ b/src/os/solaris/vm/os_solaris.cpp	Wed Nov 16 20:38:24 2011 -0500
@@ -6311,15 +6311,18 @@
 
 // is_headless_jre()
 //
 // Test for the existence of libmawt in motif21 or xawt directories
 // in order to report if we are running in a headless jre
 //
+// Since JDK8 xawt/libmawt.so was moved into the same directory
+// as libawt.so, and renamed libawt_xawt.so
+//
 bool os::is_headless_jre() {
     struct stat statbuf;
     char buf[MAXPATHLEN];
     char libmawtpath[MAXPATHLEN];
     const char *xawtstr  = "/xawt/libmawt.so";
-    const char *motifstr = "/motif21/libmawt.so";
+    const char *new_xawtstr = "/libawt_xawt.so";
     char *p;
 
     // Get path to libjvm.so
@@ -6340,9 +6343,9 @@
     strcat(libmawtpath, xawtstr);
     if (::stat(libmawtpath, &statbuf) == 0) return false;
 
-    // check motif21/libmawt.so
+    // check libawt_xawt.so
     strcpy(libmawtpath, buf);
-    strcat(libmawtpath, motifstr);
+    strcat(libmawtpath, new_xawtstr);
     if (::stat(libmawtpath, &statbuf) == 0) return false;
 
     return true;
@@ -6311,15 +6311,18 @@
 // is_headless_jre()
 //
-// Test for the existence of libmawt in motif21 or xawt directories
+// Test for the existence of xawt/libmawt.so or libawt_xawt.so
 // in order to report if we are running in a headless jre
 //